//// [parserFunctionDeclaration4.ts]
function foo();
function bar() { }

//// [parserFunctionDeclaration4.js]
function bar() { }
